package Daje::Plugin::Languages::Helpers;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Languages::Helpers - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Languages::Helpers;
#
#       my $class = Daje::Plugin::Languages::Helpers->new();
#       $app->helper(
#           v_languages_types => sub {
#               state  $v_languages_types = Daje::Database::Model::vLanguagesTypes->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_translations => sub {
#               state  $v_languages_translations = Daje::Database::Model::vLanguagesTranslations->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_lan => sub {
#               state  $v_languages_lan = Daje::Database::Model::vLanguagesLan->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_translation_keys => sub {
#               state  $v_languages_translation_keys = Daje::Database::Model::vLanguagesTranslationKeys->new(db => shift->pg->db)
#        });#
#       $app->helper(
#           v_languages_types_list => sub {
#               state  $v_languages_types_list = Daje::Database::Model::vLanguagesTypesList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_translations_list => sub {
#               state  $v_languages_translations_list = Daje::Database::Model::vLanguagesTranslationsList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_lan_list => sub {
#               state  $v_languages_lan_list = Daje::Database::Model::vLanguagesLanList->new(db => shift->pg->db)
#        });
#       $app->helper(
#           v_languages_translation_keys_list => sub {
#               state  $v_languages_translation_keys_list = Daje::Database::Model::vLanguagesTranslationKeysList->new(db => shift->pg->db)
#        });#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Languages::Helpers is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-25 11:52:04.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-25 11:52:04 -->

use Daje::Database::View::vLanguagesTypes;
use Daje::Database::View::vLanguagesTranslations;
use Daje::Database::View::vLanguagesLan;
use Daje::Database::View::vLanguagesTranslationKeys;# Lists
use Daje::Database::View::vLanguagesTypesList;
use Daje::Database::View::vLanguagesTranslationsList;
use Daje::Database::View::vLanguagesLanList;
use Daje::Database::View::vLanguagesTranslationKeysList;

our $VERSION = '0.01';

sub helpers($self, $app, $config) {

    $app->helper(
        v_languages_types => sub {
            state  $v_languages_types = Daje::Database::View::vLanguagesTypes->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_translations => sub {
            state  $v_languages_translations = Daje::Database::View::vLanguagesTranslations->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_lan => sub {
            state  $v_languages_lan = Daje::Database::View::vLanguagesLan->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_translation_keys => sub {
            state  $v_languages_translation_keys = Daje::Database::View::vLanguagesTranslationKeys->new(db => shift->pg->db)
        });    # Lists
    $app->helper(
        v_languages_types_list => sub {
            state  $v_languages_types_list = Daje::Database::View::vLanguagesTypesList->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_translations_list => sub {
            state  $v_languages_translations_list = Daje::Database::View::vLanguagesTranslationsList->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_lan_list => sub {
            state  $v_languages_lan_list = Daje::Database::View::vLanguagesLanList->new(db => shift->pg->db)
        });
    $app->helper(
        v_languages_translation_keys_list => sub {
            state  $v_languages_translation_keys_list = Daje::Database::View::vLanguagesTranslationKeysList->new(db => shift->pg->db)
        });}

1;



