package Daje::Controller::Languages::Super::LanguagesLanList;
use Mojo::Base 'Mojolicious::Controller', -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Controller::Languages::Super::LanguagesLanList - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Controller::Languages::Super::vLanguagesLan##
#
# DESCRIPTION
# ===========
#
# Daje::Controller::Languages::Super::LanguagesLan is a standard controller
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#
# This file is generated automatically by Daje Tools 2026-02-25 11:52:04.
# It will be re-generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-25 11:52:04 -->

our $VERSION = '0.01';

sub load_all_languages_lan($self) {
    $self->app->log->debug('Daje::Controller::Super::LanguagesLanList::load_all_languages_lan ');
    $self->render_later;
    my ($companies_pkey, $users_pkey) = $self->jwt->companies_users_pkey(
         $self->req->headers->header('X-Token-Check')
    );

    $self->app->log->debug($self->req->headers->header('X-Token-Check'));
    # my $setting = $self->param('setting');
    $self->v_languages_lan_list->load_all_languages_lan_p()->then(sub($result) {
        $self->render(json => $result->{data});
    })->catch(sub($err) {
        $self->app->log->error('Daje::Controller::Super::LanguagesLanList::load_all_languages_lan ' . $err);
        $self->render
    });
}

1;

