package Daje::Database::Model::Super::LanguagesLan;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;
use v5.42;

# NAME
# ====
#
# Daje::Database::Model::Super::LanguagesLan - Daje db model
#
# SYNOPSIS
# ========
#
#
#       use Daje::Database::Model::Super::LanguagesLan;
#
#       my $table = Daje::Database::Model::Super::LanguagesLan->new(db => $db);
#
#       my $result = $table->load_languages_lan_pkey($self, $languages_lan_pkey);
##
#       my $result = $table->insert($self, $data);
#
#       $table->update($self, $data) ;
#
#
# DESCRIPTION
# ===========
#
# Daje::Database::Model::Super::LanguagesLan is a Model super class
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-25 11:52:03.
# It will be re-created by Daje Tools again and any changes
# will be over written.
#
# <!-- Autogenerated file 2026-02-25 11:52:03 -->

our $VERSION = '0.01';

has 'fields' => '"languages_lan_pkey", "editnum", "insby", "insdatetime", "modby", "moddatetime","language","browser_code","iso_code"';
has 'primary_key_name' => "languages_lan_pkey";
has 'table_name' => "languages_lan"; # 
has 'mandatory' => 'language,browser_code,iso_code,';
has 'workflow' => '';

async sub load_languages_lan_pkey_p($self, $languages_lan_pkey) {
    return $self->load_languages_lan_pkey($languages_lan_pkey);
}

sub load_languages_lan_pkey($self, $languages_lan_pkey) {
    return $self->load_pk(
        $self->table_name, $self->fields(), $self->primary_key_name(), $languages_lan_pkey
    );
}

sub insert($self, $data) {
    my $result = $self->SUPER::insert(
        $self->table_name, $data, $self->primary_key_name
    );
    return $result;
}

sub update($self, $data) {
    return $self->SUPER::update
    (
        $self->table_name, $data,
            {
                $self->primary_key_name() => $data->{$self->primary_key_name()}
            }
    );
}

sub delete($self, $primary_key) {
    return $self->SUPER::delete($self->table_name, { $self->primary_key_name() => $primary_key});
}
1;

