package Daje::Database::View::Super::vLanguagesTranslationKeys;
use Mojo::Base 'Daje::Database::Model::Super::Common::Base', -base, -signatures, -async_await;
use v5.42;

# NAME
# ====
#
# Daje::Database::View::Super::vLanguagesTranslationKeys - Daje db model
#
# SYNOPSIS
# ========
#
#
#       use Daje::Database::View::Super::vLanguagesTranslationKeys;
#
#       my $table = Daje::Database::View::Super::vLanguagesTranslationKeys->new(db => $db);
#
#       my $result = $table->load_languages_translation_keys_pkey($self, $languages_translation_keys_pkey);
#
#       my $result = $table->load_languages_types_fkey($self, $languages_types_fkey);
##
#
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::Super::vLanguagesTranslationKeys is a View super class
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-25 11:52:03.
# It will be re-created by Daje Tools again and any changes
# will be over written.
#
# <!-- Autogenerated file 2026-02-25 11:52:03 -->

our $VERSION = '0.01';

has 'fields' => '"languages_translation_keys_pkey", "editnum", "insby", "insdatetime", "modby", "moddatetime","plugin","field","languages_types_fkey","key","comment"';
has 'primary_key_name' => "languages_translation_keys_pkey";
has 'table_name' => "v_languages_translation_keys";


async sub load_languages_types_fkey_p($self, $languages_types_fkey) {
    return $self->load_languages_types_fkey($languages_types_fkey);
}

sub load_languages_types_fkey($self, $languages_types_fkey) {
    return $self->load_fkey(
        $self->table_name, $self->fields(), "languages_types_fkey", $languages_types_fkey
    );
}
async sub load_languages_translation_keys_pkey_p($self, $languages_translation_keys_pkey) {
    return $self->load_languages_translation_keys_pkey($languages_translation_keys_pkey);
}

sub load_languages_translation_keys_pkey($self, $languages_translation_keys_pkey) {
    return $self->load_pk(
        $self->table_name, $self->fields(), $self->primary_key_name(), $languages_translation_keys_pkey
    );
}

1;

