package Daje::Database::View::vLanguagesLan;
use Mojo::Base 'Daje::Database::View::Super::vLanguagesLan', -base, -async_await, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Database::View::vLanguagesLan - View class
#
# SYNOPSIS
# ========
#
#       use Daje::Database::View::vLanguagesLan;
#
#       my $class = Daje::Database::View::vLanguagesLan->new(db => $db);
#
# DESCRIPTION
# ===========
#
# Daje::Database::View::vLanguagesLan is the View
#
# class that's only generated once. It inherits all
#
# methods from Daje::Database::View::Super::vLanguagesLan#
# This class is meant for non standard methods.
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated once automatically by Daje Tools 2026-02-25 11:52:04.
# It will not be touched by Daje Tools again.
# <!-- Autogenerated file 2026-02-25 11:52:04 -->


our $VERSION = '0.01';

1;

