package Daje::Plugin::Languages::Routes;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Languages::Routes - Model class
#
# SYNOPSIS
# ========
#
#       use Daje::Plugin::Languages::Routes;
#
#       my $class = Daje::Plugin::Languages::Routes->new();
#       $r->get('/languages/api/v1/types/:languages_types_pkey');
#       $r->get('/languages/api/v1/translations/:languages_translations_pkey');
#       $r->get('/languages/api/v1/translations_lan/:languages_lan_fkey');

       
#       $r->get('/languages/api/v1/translations_translation_keys/:languages_translation_keys_fkey');

       
#       $r->get('/languages/api/v1/lan/:languages_lan_pkey');
#       $r->get('/languages/api/v1/translation_keys/:languages_translation_keys_pkey');
#       $r->get('/languages/api/v1/translation_keys_types/:languages_types_fkey');

       #
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Languages::Routes is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-25 11:52:04.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-25 11:52:04 -->

our $VERSION = '0.01';

sub routes($self, $app, $config) {
    my $r = $app->auth;

    $r->get('v1/types_list_all/')->to('LanguagesTypesList#load_all_languages_types');
    $r->get('v1/translations_list_all/')->to('LanguagesTranslationsList#load_all_languages_translations');
    $r->get('v1/translations_lan_list/:languages_lan_fkey')->to('LanguagesTranslations#load_list_languages_lan_fkey');
    $r->get('v1/translations_translation_keys_list/:languages_translation_keys_fkey')->to('LanguagesTranslations#load_list_languages_translation_keys_fkey');
    $r->get('v1/lan_list_all/')->to('LanguagesLanList#load_all_languages_lan');
    $r->get('v1/translation_keys_list_all/')->to('LanguagesTranslationKeysList#load_all_languages_translation_keys');
    $r->get('v1/translation_keys_types_list/:languages_types_fkey')->to('LanguagesTranslationKeys#load_list_languages_types_fkey');
    $r->get('v1/types/:languages_types_pkey')->to('LanguagesTypes#load_languages_types_pkey');
    $r->get('v1/translations_lan/:languages_lan_fkey')->to('LanguagesTranslations#load_languages_lan_fkey');
    $r->get('v1/translations_translation_keys/:languages_translation_keys_fkey')->to('LanguagesTranslations#load_languages_translation_keys_fkey');    $r->get('v1/translations/:languages_translations_pkey')->to('LanguagesTranslations#load_languages_translations_pkey');    $r->get('v1/lan/:languages_lan_pkey')->to('LanguagesLan#load_languages_lan_pkey');
    $r->get('v1/translation_keys_types/:languages_types_fkey')->to('LanguagesTranslationKeys#load_languages_types_fkey');    $r->get('v1/translation_keys/:languages_translation_keys_pkey')->to('LanguagesTranslationKeys#load_languages_translation_keys_pkey');
}

