package Daje::Plugin::Languages::Languages;
use Mojo::Base -base, -signatures;
use v5.42;

# NAME
# ====
#
# Daje::Plugin::Languages::Languages - Model class
#
# SYNOPSIS
# ========
#
#
#
#
# DESCRIPTION
# ===========
#
# Daje::Plugin::Languages::Languages is the standard routes
#
# METHODS
# =======
#
#
# LICENSE
# =======
#
# Copyright (C) janeskil1525.
#
# This library is free software; you can redistribute it and/or modify
# it under the same terms as Perl itself.
#
# AUTHOR
# ======
#
# janeskil1525 E<lt>janeskil1525@gmail.com
#

# This file is generated automatically by Daje Tools 2026-02-25 11:52:04.
# It will be generated by Daje Tools again.
# <!-- Autogenerated file 2026-02-25 11:52:04 -->

use Daje::Helper::Languages::InsertKeys;

has 'db';

sub language($self) {

    try {
        my $tx = $self->db->begin;
        my @keys;
        push @keys, {
                plugin => 'languages',
                key => 'types',
                field => 'table',
                type => 'Label',
                translation => 'Types',
                comment => 'Translation types, field tooltip grid ',
            };
          push @keys,  {
                plugin => 'languages',
                key => 'types',
                field => 'type',
                type => 'Label',
                translation => 'Type',
                comment => 'Type of translation, field tooltip help etc'
            };
           push @keys, {
                plugin => 'languages',
                key => 'types',
                field => 'type',
                type => 'Tool tips',
                translation => 'Type of translation, field tooltip help etc',
                comment => 'Type of translation, field tooltip help etc'
            };
         
        push @keys, {
                plugin => 'languages',
                key => 'translations',
                field => 'table',
                type => 'Label',
                translation => 'Translations',
                comment => 'Translations',
            };
          push @keys,  {
                plugin => 'languages',
                key => 'translations',
                field => 'lan',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'languages',
                key => 'translations',
                field => 'lan',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translations',
                field => 'translation_keys',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'languages',
                key => 'translations',
                field => 'translation_keys',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translations',
                field => 'translation',
                type => 'Label',
                translation => 'Translation',
                comment => 'Translation to selected language'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translations',
                field => 'translation',
                type => 'Tool tips',
                translation => 'Translation to selected language',
                comment => 'Translation to selected language'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translations',
                field => 'locked',
                type => 'Label',
                translation => 'Locked',
                comment => 'Translation locked for automatic updates'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translations',
                field => 'locked',
                type => 'Tool tips',
                translation => 'Translation locked for automatic updates',
                comment => 'Translation locked for automatic updates'
            };
         
        push @keys, {
                plugin => 'languages',
                key => 'lan',
                field => 'table',
                type => 'Label',
                translation => 'Language',
                comment => 'The supported languages',
            };
          push @keys,  {
                plugin => 'languages',
                key => 'lan',
                field => 'language',
                type => 'Label',
                translation => 'Language',
                comment => 'Language full name'
            };
           push @keys, {
                plugin => 'languages',
                key => 'lan',
                field => 'language',
                type => 'Tool tips',
                translation => 'Language full name',
                comment => 'Language full name'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'lan',
                field => 'browser_code',
                type => 'Label',
                translation => 'Browser code',
                comment => 'Language code in the browser'
            };
           push @keys, {
                plugin => 'languages',
                key => 'lan',
                field => 'browser_code',
                type => 'Tool tips',
                translation => 'Language code in the browser',
                comment => 'Language code in the browser'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'lan',
                field => 'iso_code',
                type => 'Label',
                translation => 'ISO Code',
                comment => 'Language ISO Code'
            };
           push @keys, {
                plugin => 'languages',
                key => 'lan',
                field => 'iso_code',
                type => 'Tool tips',
                translation => 'Language ISO Code',
                comment => 'Language ISO Code'
            };
         
        push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'table',
                type => 'Label',
                translation => '',
                comment => '',
            };
          push @keys,  {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'plugin',
                type => 'Label',
                translation => '',
                comment => ''
            };
           push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'plugin',
                type => 'Tool tips',
                translation => '',
                comment => ''
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'field',
                type => 'Label',
                translation => 'Field',
                comment => 'Translated field'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'field',
                type => 'Tool tips',
                translation => 'Translated field',
                comment => 'Translated field'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'types',
                type => 'Label',
                translation => 'Types',
                comment => 'Type of translation'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'types',
                type => 'Tool tips',
                translation => 'Type of translation, field tooltip help etc',
                comment => 'Type of translation'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'key',
                type => 'Label',
                translation => 'Key',
                comment => 'Key or table the translation belongs to'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'key',
                type => 'Tool tips',
                translation => 'Key or table the translation belongs to',
                comment => 'Key or table the translation belongs to'
            };
         
          push @keys,  {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'comment',
                type => 'Label',
                translation => 'Comment',
                comment => 'Comment to help understand context'
            };
           push @keys, {
                plugin => 'languages',
                key => 'translation_keys',
                field => 'comment',
                type => 'Tool tips',
                translation => 'Comment to help understand context',
                comment => 'Comment to help understand context'
            };
         

        Daje::Helper::Languages::InsertKeys->new(
            db => $self->db
        )->process(
             \@keys
        );
        $tx->commit();
    } catch($e) {
        say $e;
    }
}

1;


